﻿using System;
using Microsoft.SharePoint;

namespace Layer2.Products.BdlcApiExamples
{
    class CheckIfListsExistsInConfigList
    {
        /// <summary>
        /// check if the given SP list is already in use as BDLC connected list
        /// </summary>
        /// <param name="bdlcConfigList">the BDLC Configuration list. Best read the GUID of it before and access it through  _web.Lists.GetList(configListId, true)</param>
        /// <param name="listToCheck">The list in question</param>
        /// <param name="listWeb">SPWeb where the list is in</param>
        /// <returns>TRUE if this list is BDLC connected, otherwise FALSE</returns>
        internal static bool Exists(SPList bdlcConfigList, SPList listToCheck)
        {
            string queryString = "<Where><And><Eq><FieldRef Name='{0}' /><Value Type='Text'>{1}</Value></Eq><Eq><FieldRef Name='{2}' /><Value Type='Text'>{3}</Value></Eq></And></Where><OrderBy><FieldRef Name='ID' /></OrderBy>";
            queryString = String.Format(queryString, "bdlcListId", listToCheck.ID, "bdlcWebId", listToCheck.ParentWeb.ID);
            SPQuery query = new SPQuery { Query = queryString };

            var results = bdlcConfigList.GetItems(query);
            return (results != null && results.Count > 0);
        }

        internal static SPListItem GetConfigItem(SPList bdlcConfigList, SPList listToCheck)
        {
            string queryString = "<Where><And><Eq><FieldRef Name='{0}' /><Value Type='Text'>{1}</Value></Eq><Eq><FieldRef Name='{2}' /><Value Type='Text'>{3}</Value></Eq></And></Where><OrderBy><FieldRef Name='ID' /></OrderBy>";
            queryString = String.Format(queryString, "bdlcListId", listToCheck.ID, "bdlcWebId", listToCheck.ParentWeb.ID);
            SPQuery query = new SPQuery { Query = queryString };

            var results = bdlcConfigList.GetItems(query);
            if (results == null || results.Count == 0)
                return null;

            return results[0];
        }
    }
}
